@@ -30,11 +30,12 @@ class OnDeletedMessages(BaseClient):
         filters=None,
         group: int = 0
     ) -> callable:
-        """Use this decorator to automatically register a function for handling deleted messages.
+        """Decorator for handling deleted messages.
+
         This does the same thing as :meth:`add_handler` using the :class:`DeletedMessagesHandler`.
 
-        Args:
-            filters (:obj:`Filters <pyrogram.Filters>`):
+        Parameters:
+            filters (:obj:`Filters`):
                 Pass one or more filters to allow only a subset of messages to be passed
                 in your function.
 
