@@ -24,16 +24,18 @@ from pyrogram.client.ext import BaseClient
 
 
 class DownloadMedia(BaseClient):
-    def download_media(self,
-                       message: Union["pyrogram.Message", str],
-                       file_name: str = "",
-                       block: bool = True,
-                       progress: callable = None,
-                       progress_args: tuple = ()) -> Union[str, None]:
-        """Use this method to download the media from a Message.
+    def download_media(
+        self,
+        message: Union["pyrogram.Message", str],
+        file_name: str = "",
+        block: bool = True,
+        progress: callable = None,
+        progress_args: tuple = ()
+    ) -> Union[str, None]:
+        """Download the media from a message.
 
-        Args:
-            message (:obj:`Message <pyrogram.Message>` | ``str``):
+        Parameters:
+            message (:obj:`Message` | ``str``):
                 Pass a Message containing the media, the media itself (message.audio, message.video, ...) or
                 the file id as string.
 
@@ -57,7 +59,7 @@ class DownloadMedia(BaseClient):
                 a chat_id and a message_id in order to edit a message with the updated progress.
 
         Other Parameters:
-            client (:obj:`Client <pyrogram.Client>`):
+            client (:obj:`Client`):
                 The Client itself, useful when you want to call other API methods inside the callback function.
 
             current (``int``):
@@ -71,11 +73,11 @@ class DownloadMedia(BaseClient):
                 You can either keep *\*args* or add every single extra argument in your function signature.
 
         Returns:
-            On success, the absolute path of the downloaded file as string is returned, None otherwise.
-            In case the download is deliberately stopped with :meth:`stop_transmission`, None is returned as well.
+            ``str`` | ``None``: On success, the absolute path of the downloaded file is returned, otherwise, in case
+            the download failed or was deliberately stopped with :meth:`stop_transmission`, None is returned.
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+            RPCError: In case of a Telegram RPC error.
             ``ValueError`` if the message doesn't contain any downloadable media
         """
         error_message = "This message doesn't contain any downloadable media"
@@ -106,15 +108,15 @@ class DownloadMedia(BaseClient):
             else:
                 raise ValueError(error_message)
         elif isinstance(message, (
-                pyrogram.Photo,
-                pyrogram.PhotoSize,
-                pyrogram.Audio,
-                pyrogram.Document,
-                pyrogram.Video,
-                pyrogram.Voice,
-                pyrogram.VideoNote,
-                pyrogram.Sticker,
-                pyrogram.Animation
+            pyrogram.Photo,
+            pyrogram.PhotoSize,
+            pyrogram.Audio,
+            pyrogram.Document,
+            pyrogram.Video,
+            pyrogram.Voice,
+            pyrogram.VideoNote,
+            pyrogram.Sticker,
+            pyrogram.Animation
         )):
             if isinstance(message, pyrogram.Photo):
                 media = pyrogram.Document(
