@@ -17,35 +17,38 @@
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 import binascii
-import mimetypes
 import os
 import struct
 from typing import Union
 
 import pyrogram
 from pyrogram.api import functions, types
-from pyrogram.api.errors import FileIdInvalid, FilePartMissing
+from pyrogram.errors import FileIdInvalid, FilePartMissing
 from pyrogram.client.ext import BaseClient, utils
 
 
 class SendVideoNote(BaseClient):
-    def send_video_note(self,
-                        chat_id: Union[int, str],
-                        video_note: str,
-                        duration: int = 0,
-                        length: int = 1,
-                        thumb: str = None,
-                        disable_notification: bool = None,
-                        reply_to_message_id: int = None,
-                        reply_markup: Union["pyrogram.InlineKeyboardMarkup",
-                                            "pyrogram.ReplyKeyboardMarkup",
-                                            "pyrogram.ReplyKeyboardRemove",
-                                            "pyrogram.ForceReply"] = None,
-                        progress: callable = None,
-                        progress_args: tuple = ()) -> "pyrogram.Message":
-        """Use this method to send video messages.
+    def send_video_note(
+        self,
+        chat_id: Union[int, str],
+        video_note: str,
+        duration: int = 0,
+        length: int = 1,
+        thumb: str = None,
+        disable_notification: bool = None,
+        reply_to_message_id: int = None,
+        reply_markup: Union[
+            "pyrogram.InlineKeyboardMarkup",
+            "pyrogram.ReplyKeyboardMarkup",
+            "pyrogram.ReplyKeyboardRemove",
+            "pyrogram.ForceReply"
+        ] = None,
+        progress: callable = None,
+        progress_args: tuple = ()
+    ) -> Union["pyrogram.Message", None]:
+        """Send video messages.
 
-        Args:
+        Parameters:
             chat_id (``int`` | ``str``):
                 Unique identifier (int) or username (str) of the target chat.
                 For your personal cloud (Saved Messages) you can simply use "me" or "self".
@@ -66,7 +69,7 @@ class SendVideoNote(BaseClient):
             thumb (``str``, *optional*):
                 Thumbnail of the video sent.
                 The thumbnail should be in JPEG format and less than 200 KB in size.
-                A thumbnail's width and height should not exceed 90 pixels.
+                A thumbnail's width and height should not exceed 320 pixels.
                 Thumbnails can't be reused and can be only uploaded as a new file.
 
             disable_notification (``bool``, *optional*):
@@ -90,7 +93,7 @@ class SendVideoNote(BaseClient):
                 a chat_id and a message_id in order to edit a message with the updated progress.
 
         Other Parameters:
-            client (:obj:`Client <pyrogram.Client>`):
+            client (:obj:`Client`):
                 The Client itself, useful when you want to call other API methods inside the callback function.
 
             current (``int``):
@@ -104,73 +107,77 @@ class SendVideoNote(BaseClient):
                 You can either keep *\*args* or add every single extra argument in your function signature.
 
         Returns:
-            On success, the sent :obj:`Message <pyrogram.Message>` is returned.
+            :obj:`Message` | ``None``: On success, the sent video note message is returned, otherwise, in case the
+            pload is deliberately stopped with :meth:`stop_transmission`, None is returned.
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+            RPCError: In case of a Telegram RPC error.
         """
         file = None
 
-        if os.path.exists(video_note):
-            thumb = None if thumb is None else self.save_file(thumb)
-            file = self.save_file(video_note, progress=progress, progress_args=progress_args)
-            media = types.InputMediaUploadedDocument(
-                mime_type=mimetypes.types_map[".mp4"],
-                file=file,
-                thumb=thumb,
-                attributes=[
-                    types.DocumentAttributeVideo(
-                        round_message=True,
-                        duration=duration,
-                        w=length,
-                        h=length
-                    )
-                ]
-            )
-        else:
-            try:
-                decoded = utils.decode(video_note)
-                fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
-                unpacked = struct.unpack(fmt, decoded)
-            except (AssertionError, binascii.Error, struct.error):
-                raise FileIdInvalid from None
-            else:
-                if unpacked[0] != 13:
-                    media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
-
-                    if media_type:
-                        raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
-                    else:
-                        raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
-
-                media = types.InputMediaDocument(
-                    id=types.InputDocument(
-                        id=unpacked[2],
-                        access_hash=unpacked[3],
-                        file_reference=b""
-                    )
-                )
-
-        while True:
-            try:
-                r = self.send(
-                    functions.messages.SendMedia(
-                        peer=self.resolve_peer(chat_id),
-                        media=media,
-                        silent=disable_notification or None,
-                        reply_to_msg_id=reply_to_message_id,
-                        random_id=self.rnd_id(),
-                        reply_markup=reply_markup.write() if reply_markup else None,
-                        message=""
-                    )
-                )
-            except FilePartMissing as e:
-                self.save_file(video_note, file_id=file.id, file_part=e.x)
-            else:
-                for i in r.updates:
-                    if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage)):
-                        return pyrogram.Message._parse(
-                            self, i.message,
-                            {i.id: i for i in r.users},
-                            {i.id: i for i in r.chats}
+        try:
+            if os.path.exists(video_note):
+                thumb = None if thumb is None else self.save_file(thumb)
+                file = self.save_file(video_note, progress=progress, progress_args=progress_args)
+                media = types.InputMediaUploadedDocument(
+                    mime_type=self.guess_mime_type(video_note) or "video/mp4",
+                    file=file,
+                    thumb=thumb,
+                    attributes=[
+                        types.DocumentAttributeVideo(
+                            round_message=True,
+                            duration=duration,
+                            w=length,
+                            h=length
                         )
+                    ]
+                )
+            else:
+                try:
+                    decoded = utils.decode(video_note)
+                    fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
+                    unpacked = struct.unpack(fmt, decoded)
+                except (AssertionError, binascii.Error, struct.error):
+                    raise FileIdInvalid from None
+                else:
+                    if unpacked[0] != 13:
+                        media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
+
+                        if media_type:
+                            raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
+                        else:
+                            raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
+
+                    media = types.InputMediaDocument(
+                        id=types.InputDocument(
+                            id=unpacked[2],
+                            access_hash=unpacked[3],
+                            file_reference=b""
+                        )
+                    )
+
+            while True:
+                try:
+                    r = self.send(
+                        functions.messages.SendMedia(
+                            peer=self.resolve_peer(chat_id),
+                            media=media,
+                            silent=disable_notification or None,
+                            reply_to_msg_id=reply_to_message_id,
+                            random_id=self.rnd_id(),
+                            reply_markup=reply_markup.write() if reply_markup else None,
+                            message=""
+                        )
+                    )
+                except FilePartMissing as e:
+                    self.save_file(video_note, file_id=file.id, file_part=e.x)
+                else:
+                    for i in r.updates:
+                        if isinstance(i, (types.UpdateNewMessage, types.UpdateNewChannelMessage)):
+                            return pyrogram.Message._parse(
+                                self, i.message,
+                                {i.id: i for i in r.users},
+                                {i.id: i for i in r.chats}
+                            )
+        except BaseClient.StopTransmission:
+            return None
