@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -21,29 +21,31 @@ from ...ext import BaseClient
 
 
 class SetUserProfilePhoto(BaseClient):
-    def set_user_profile_photo(self,
-                               photo: str) -> bool:
-        """Use this method to set a new profile photo.
+    def set_user_profile_photo(
+        self,
+        photo: str
+    ) -> bool:
+        """Set a new profile photo.
 
         This method only works for Users.
         Bots profile photos must be set using BotFather.
 
-        Args:
+        Parameters:
             photo (``str``):
                 Profile photo to set.
                 Pass a file path as string to upload a new photo that exists on your local machine.
 
         Returns:
-            True on success.
+            ``bool``: True on success.
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+            RPCError: In case of a Telegram RPC error.
         """
 
         return bool(
             self.send(
                 functions.photos.UploadProfilePhoto(
-                    self.save_file(photo)
+                    file=self.save_file(photo)
                 )
             )
         )
