@@ -20,18 +20,20 @@ from ..pyrogram_type import PyrogramType
 
 
 class InputMedia(PyrogramType):
-    """This object represents the content of a media message to be sent. It should be one of:
+    """Content of a media message to be sent.
 
-    - :obj:`InputMediaAnimation <pyrogram.InputMediaAnimation>`
-    - :obj:`InputMediaDocument <pyrogram.InputMediaDocument>`
-    - :obj:`InputMediaAudio <pyrogram.InputMediaAudio>`
-    - :obj:`InputMediaPhoto <pyrogram.InputMediaPhoto>`
-    - :obj:`InputMediaVideo <pyrogram.InputMediaVideo>`
+    It should be one of:
+
+    - :obj:`InputMediaAnimation`
+    - :obj:`InputMediaDocument`
+    - :obj:`InputMediaAudio`
+    - :obj:`InputMediaPhoto`
+    - :obj:`InputMediaVideo`
     """
     __slots__ = ["media", "caption", "parse_mode"]
 
     def __init__(self, media: str, caption: str, parse_mode: str):
-        super().__init__(None)
+        super().__init__()
 
         self.media = media
         self.caption = caption
