@@ -23,9 +23,9 @@ from ..pyrogram_type import PyrogramType
 
 
 class Contact(PyrogramType):
-    """This object represents a phone contact.
+    """A phone contact.
 
-    Args:
+    Parameters:
         phone_number (``str``):
             Contact's phone number.
 
@@ -47,7 +47,7 @@ class Contact(PyrogramType):
     def __init__(
         self,
         *,
-        client: "pyrogram.client.ext.BaseClient",
+        client: "pyrogram.BaseClient" = None,
         phone_number: str,
         first_name: str,
         last_name: str = None,
